@@ -697,30 +697,44 @@ if (isset($my_die)) {
 
 if ($go_sql) {
 
-    // parse sql query
-    include_once 'libraries/parse_analyze.inc.php';
+    if (! empty($sql_data) && ($sql_data['valid_queries'] > 1)) {
+        $_SESSION['is_multi_query'] = true;
+        $sql_queries = $sql_data['valid_sql'];
+    } else {
+        $sql_queries = array($sql_query);
+    }
 
-    PMA_executeQueryAndSendQueryResponse(
-        $analyzed_sql_results, false, $db, $table, null, $import_text, null,
-        $analyzed_sql_results['is_affected'], null,
-        null, null, $sql_data, $goto, $pmaThemeImage, null, null, null, $sql_query,
-        null, null
-    );
+    $html_output = '';
+    foreach ($sql_queries as $sql_query) {
+        // parse sql query
+        include 'libraries/parse_analyze.inc.php';
+
+        $html_output .= PMA_executeQueryAndGetQueryResponse(
+            $analyzed_sql_results, false, $db, $table, null,
+            $sql_query, null, $analyzed_sql_results['is_affected'],
+            null, null, null, $goto, $pmaThemeImage,
+            null, null, null, $sql_query, null, null
+        );
+    }
 
     if (!isset($ajax_reload)) {
         $ajax_reload = array();
     }
-    $ajax_reload['table_name'] = $table;
-
+    if (isset($table)) {
+        $ajax_reload['table_name'] = $table;
+    }
     $response = PMA_Response::getInstance();
     $response->addJSON('ajax_reload', $ajax_reload);
+    $response->addHTML($html_output);
+    exit();
+
 } else if ($result) {
     // Save a Bookmark with more than one queries (if Bookmark label given).
     if (! empty($_POST['bkm_label']) && ! empty($import_text)) {
         $cfgBookmark = PMA_Bookmark_getParams();
         PMA_storeTheQueryAsBookmark(
             $db, $cfgBookmark['user'],
-            $import_text, $_POST['bkm_label'],
+            $_REQUEST['sql_query'], $_POST['bkm_label'],
             isset($_POST['bkm_replace']) ? $_POST['bkm_replace'] : null
         );
     }
